@@ -1,5 +1,4 @@
 
-#' @importFrom XML xmlParse xmlToList xmlToDataFrame
 #' @importFrom utils download.file
 #' @import dplyr
 
@@ -7,7 +6,6 @@
 # unique filenames in the latest release and return those
 
 get_abs_xml_metadata <- function(url, issue = "latest") {
-
   if (!issue %in% c("latest", "all")) {
     stop("`issue` argument in get_abs_xml_metadata() must be either 'latest' or 'all'")
   }
@@ -16,11 +14,13 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
     stop("`url` argument to get_abs_xml_metadata() must be a string.")
   }
 
-  ProductReleaseDate = TableOrder = cat_no = ProductIssue = NULL
+  ProductReleaseDate <- TableOrder <- cat_no <- ProductIssue <- NULL
 
   # Download the first page of metadata
-  first_url <- paste0(url,
-                      "&pg=1")
+  first_url <- paste0(
+    url,
+    "&pg=1"
+  )
 
   # Some ABS Time Series in the directory start with a leading zero, as in
   # Table 01 rather than Table 1; the 0 needs to be included. Here we first test
@@ -28,48 +28,44 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
   # doesn't work then we try with a leading zero ("01"). If that fails,
   # it's an error.
 
-  first_page_location <- file.path(tempdir(), "temp_readabs_xml.xml")
-
-  utils::download.file(first_url,
-                       first_page_location,
-                       quiet = TRUE,
-                       cacheOK = FALSE)
-
-  first_page <- XML::xmlParse(first_page_location)
-
-  first_page_list <- XML::xmlToList(first_page)
-
-  first_url_works <- ifelse(!is.null(first_page_list), TRUE, FALSE)
+  first_page <- xml2::read_xml(first_url, encoding = "ISO-8859-1")
+  first_page_list <- xml2::as_list(first_page)
+  first_page_list <- first_page_list[[1]]
+  first_url_works <- ifelse(length(first_page_list) > 0,
+    TRUE,
+    FALSE
+  )
 
   if (!first_url_works) {
     if (!grepl("ttitle", first_url)) { # this is the case when tables == "all"
-      stop(paste0("Cannot find valid entry for cat_no ", cat_no,
-                  " in the ABS Time Series Directory.",
-                  "Check that the cat. no. is correct, and that it contains ",
-                  "time series spreadsheets (not data cubes)."))
+      stop(paste0(
+        "Cannot find valid entry for cat_no ", cat_no,
+        " in the ABS Time Series Directory.",
+        "Check that the cat. no. is correct, and that it contains ",
+        "time series spreadsheets (not data cubes)."
+      ))
     }
 
     # now try prepending a 0 on the ttitle
 
     first_url <- gsub("ttitle=", "ttitle=0", first_url)
 
-    utils::download.file(first_url, first_page_location, quiet = TRUE,
-                         cacheOK = FALSE)
-
-    first_page <- XML::xmlParse(first_page_location)
-
-    first_page_list <- XML::xmlToList(first_page)
-
-    first_url_works <- ifelse(!is.null(first_page_list), TRUE, FALSE)
+    first_page <- xml2::read_xml(first_url, encoding = "ISO-8859-1")
+    first_page_list <- xml2::as_list(first_page)
+    first_page_list <- first_page_list[[1]]
+    first_url_works <- ifelse(length(first_page_list) > 0,
+      TRUE,
+      FALSE
+    )
 
     if (first_url_works) {
       url <- gsub("ttitle=", "ttitle=0", url)
-
     } else {
-      stop(paste0("Cannot find valid entry for cat_no ", cat_no,
-                  " in the ABS Time Series Directory"))
+      stop(paste0(
+        "Cannot find valid entry for cat_no ", cat_no,
+        " in the ABS Time Series Directory"
+      ))
     }
-
   }
 
 
@@ -79,19 +75,15 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
     tot_pages <- as.numeric(first_page_list$NumPages)
   }
 
-  if (!is.numeric(tot_pages)) {
-    stop("Can't tell how many pages of XML match your query")
-  }
-
-  all_pages <- sort(seq(as.numeric(tot_pages):1), decreasing = TRUE)
+  all_pages <- rev(c(1:tot_pages))
 
   # Extract the date on the first page of the metadata
   # (it'll be the oldest in the directory)
-  first_page_df <- XML::xmlToDataFrame(first_page, stringsAsFactors = FALSE)
+  # first_page_df <- XML::xmlToDataFrame(first_page, stringsAsFactors = FALSE)
 
-  max_date <- max(as.Date(first_page_df$ProductReleaseDate,
-                          format = "%d/%m/%Y"),
-                  na.rm = TRUE)
+  max_date <- as.Date(first_page_list$Series$ProductReleaseDate[[1]],
+    format = "%d/%m/%Y"
+  )
 
   # create list of URLs of XML metadata to scrape
   full_urls <- paste0(url, "&pg=", all_pages)
@@ -105,7 +97,6 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
   current <- TRUE
   xml_dfs <- list()
   while (current == TRUE) {
-
     xml_df <- get_xml_df(url = full_urls[i])
 
     xml_dfs[[i]] <- xml_df
@@ -113,7 +104,8 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
 
     if (issue == "latest") {
       date_in_df <- max(as.Date(xml_df$ProductReleaseDate, format = "%d/%m/%Y"),
-                        na.rm = TRUE)
+        na.rm = TRUE
+      )
 
       if (date_in_df >= max_date) {
         max_date <- date_in_df
@@ -130,17 +122,18 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
     if (i > tot_pages) {
       current <- FALSE
     }
-
-
   } # end while loop
 
   xml_dfs <- dplyr::bind_rows(xml_dfs)
 
   xml_dfs <- xml_dfs %>%
     dplyr::mutate(ProductIssue = as.Date(paste0("01 ", ProductIssue),
-                                         format = "%d %b %Y")) %>%
+      format = "%d %b %Y"
+    )) %>%
     dplyr::mutate_at(c("ProductReleaseDate", "SeriesStart", "SeriesEnd"),
-                     as.Date, format = "%d/%m/%Y")
+      as.Date,
+      format = "%d/%m/%Y"
+    )
 
   if (issue == "latest") {
     xml_dfs <- xml_dfs %>%
@@ -148,8 +141,7 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
   }
 
   xml_dfs <- dplyr::mutate(xml_dfs, TableOrder = as.numeric(TableOrder))
-  xml_dfs <- xml_dfs[order(xml_dfs[ , "TableOrder"]), ]
+  xml_dfs <- xml_dfs[order(xml_dfs[, "TableOrder"]), ]
 
   xml_dfs
-
 }
